searchData={"content_type":"text/markdown","items":[{"doc":"Nebulex adapter for [Cachex][Cachex].\n\n[Cachex]: http://hexdocs.pm/cachex/Cachex.html\n\nBy means of this adapter, you can configure Cachex as the cache backend\nand use it through the Nebulex API.","ref":"Nebulex.Adapters.Cachex.html","title":"Nebulex.Adapters.Cachex","type":"module"},{"doc":"Since Nebulex is just a wrapper on top of Cachex, the options are the same as\n[Cachex.start_link/1][cachex_start_link].\n\n[cachex_start_link]: https://hexdocs.pm/cachex/Cachex.html#start_link/1","ref":"Nebulex.Adapters.Cachex.html#module-options","title":"Options - Nebulex.Adapters.Cachex","type":"module"},{"doc":"You can define a cache using Cachex as follows:\n\n    defmodule MyApp.Cache do\n      use Nebulex.Cache,\n        otp_app: :my_app,\n        adapter: Nebulex.Adapters.Cachex\n    end\n\nWhere the configuration for the cache must be in your application\nenvironment, usually defined in your `config/config.exs`:\n\n    config :my_app, MyApp.Cache,\n      limit: 1_000_000,\n      stats: true,\n      ...\n\nIf your application was generated with a supervisor (by passing `--sup`\nto `mix new`) you will have a `lib/my_app/application.ex` file containing\nthe application start callback that defines and starts your supervisor.\nYou just need to edit the `start/2` function to start the cache as a\nsupervisor on your application's supervisor:\n\n    def start(_type, _args) do\n      children = [\n        {MyApp.Cache, []},\n      ]\n\n      ...\n    end\n\nSince Cachex uses macros for some configuration options, you could also\npass the options in runtime when the cache is started, either by calling\n`MyApp.Cache.start_link/1` directly, or in your app supervision tree:\n\n    def start(_type, _args) do\n      children = [\n        {MyApp.Cache, cachex_opts()},\n      ]\n\n      ...\n    end\n\n    defp cachex_opts do\n      import Cachex.Spec\n\n      [\n        expiration: expiration(\n          # default record expiration\n          default: :timer.seconds(60),\n\n          # how often cleanup should occur\n          interval: :timer.seconds(30),\n\n          # whether to enable lazy checking\n          lazy: true\n        ),\n\n        # complex limit\n        limit: limit(\n          size: 500,\n          policy: Cachex.Policy.LRW,\n          reclaim: 0.5,\n          options: []\n        ),\n\n        ...\n      ]\n    end\n\n> See [Cachex.start_link/1][cachex_start_link] for more information.","ref":"Nebulex.Adapters.Cachex.html#module-example","title":"Example - Nebulex.Adapters.Cachex","type":"module"},{"doc":"This adapter emits the recommended Telemetry events.\nSee the \"Telemetry events\" section in `Nebulex.Cache`\nfor more information.","ref":"Nebulex.Adapters.Cachex.html#module-telemetry-events","title":"Telemetry events - Nebulex.Adapters.Cachex","type":"module"},{"doc":"In the same way we use the distributed adapters and the multilevel one to\ncreate distributed topologies, we can also do the same but instead of using\nthe built-in local adapter using Cachex.\n\nFor example, let's define a multi-level cache (near cache topology), where\nthe L1 is a local cache using Cachex and the L2 is a partitioned cache.\n\n    defmodule MyApp.NearCache do\n      use Nebulex.Cache,\n        otp_app: :nebulex,\n        adapter: Nebulex.Adapters.Multilevel\n\n      defmodule L1 do\n        use Nebulex.Cache,\n          otp_app: :nebulex,\n          adapter: Nebulex.Adapters.Cachex\n      end\n\n      defmodule L2 do\n        use Nebulex.Cache,\n          otp_app: :nebulex,\n          adapter: Nebulex.Adapters.Partitioned,\n          primary_storage_adapter: Nebulex.Adapters.Cachex\n      end\n    end\n\nAnd the configuration may look like:\n\n    config :my_app, MyApp.NearCache,\n      model: :inclusive,\n      levels: [\n        {MyApp.NearCache.L1, [limit: 100_000]},\n        {MyApp.NearCache.L2, primary: [limit: 1_000_000]}\n      ]\n\n> **NOTE:** You could also use [NebulexRedisAdapter][nbx_redis_adapter] for\n  L2, it would be matter of changing the adapter for the L2 and the\n  configuration to set up Redis adapter.\n\n[nbx_redis_adapter]: https://github.com/cabol/nebulex_redis_adapter\n\nSee [Nebulex examples](https://github.com/cabol/nebulex_examples). You will\nfind examples for all different topologies, even using other adapters like\nRedis; for all examples you can just replace `Nebulex.Adapters.Local` by\n`Nebulex.Adapters.Cachex`.","ref":"Nebulex.Adapters.Cachex.html#module-distributed-caching-topologies","title":"Distributed caching topologies - Nebulex.Adapters.Cachex","type":"module"}]}